@@ -21,10 +21,10 @@ class DummyConfig(appcli.Config):
 @parametrize_from_file(
         schema=Schema({
             'obj': exec_obj,
-            'init_layers': Or(eval_layers, empty_list),
-            'load_layers': Or(eval_layers, empty_list),
-            Optional('reload_layers', default=[]):
-                Or(eval_layers, empty_list),
+            'init_layers': Or(eval_layers, empty_dict),
+            'load_layers': Or(eval_layers, empty_dict),
+            Optional('reload_layers', default={}):
+                Or(eval_layers, empty_dict),
         })
 )
 def test_init_load_reload(obj, init_layers, load_layers, reload_layers):
@@ -32,21 +32,21 @@ def test_init_load_reload(obj, init_layers, load_layers, reload_layers):
         reload_layers = load_layers
 
     appcli.init(obj)
-    assert list(appcli.model.iter_layers(obj)) == init_layers
+    assert collect_layers(obj) == init_layers
 
     try:
         obj.load()
     except AttributeError:
         appcli.load(obj)
 
-    assert list(appcli.model.iter_layers(obj)) == load_layers
+    assert collect_layers(obj) == load_layers
 
     try:
         obj.reload()
     except AttributeError:
         appcli.reload(obj)
 
-    assert list(appcli.model.iter_layers(obj)) == reload_layers
+    assert collect_layers(obj) == reload_layers
 
 def test_get_configs():
 
@@ -65,25 +65,37 @@ def test_get_configs_err():
 
     assert err.match('object not configured for use with appcli')
     assert err.match(no_templates)
+
 @parametrize_from_file(
         schema=Schema({
             'obj': exec_obj,
-            'key_map': Or({Coerce(int): [eval]}, empty_dict),
+            'bound_keys': Or([{
+                'config': Coerce(int),
+                'key': str,
+                Optional('cast', default='lambda x: x'): eval,
+            }], empty_list),
             Optional('default', default=None): Or(None, eval),
-            **error_or(
-                expected=Or([eval], empty_list),
-            ),
+            **error_or(**{
+                'expected': Or([eval], empty_list),
+            }),
         })
 )
-def test_iter_values(obj, key_map, default, expected, error):
-    configs = appcli.model.get_configs(obj)
-    key_map = {configs[i]: v for i, v in key_map.items()}
-    kwargs = {} if default is None else dict(default=default)
-
+def test_iter_values(obj, bound_keys, default, expected, error):
     appcli.init(obj)
 
+    bound_configs = appcli.model.get_bound_configs(obj)
+    bound_keys = [
+            appcli.model.BoundKey(
+                bound_configs[bk['config']],
+                key=bk['key'],
+                cast=bk['cast'],
+            )
+            for bk in bound_keys
+    ]
+    kwargs = {} if default is None else dict(default=default)
+
     with error:
-        values = appcli.model.iter_values(obj, key_map, **kwargs)
+        values = appcli.model.iter_values(obj, bound_keys, **kwargs)
         assert list(values) == expected
 
 
